Examples
========

.. toctree::
   
    Structure <examples/structure.ipynb>
    Heat <examples/heat.ipynb>
    Phonons <examples/phonons.ipynb>
    Dynamical Xray Scattering <examples/dynamical_xray.ipynb>
    Dynamical Magnetic Xray Scattering <examples/dynamical_magnetic_xray.ipynb>